@@ -297,7 +297,7 @@ class SerializerRegistry(object):
             return current is None
 
     def register_from_super_type(self, obj_type, super_type):
-        serializer = self._type_dict[super_type]
+        serializer = self._type_dict.get(super_type, None)
         if serializer is not None:
             self.safe_register_serializer(serializer, obj_type)
         return serializer
